from PIL import Image, ImageDraw, ImageFont
from random import sample

def generate(string,color_bg=False):
    colors = [(0, 0, 0), (255, 0, 0), (0, 255, 0), (0, 0, 255), (255, 255, 0), (0, 255, 255), (255, 0, 255), (192, 192, 192), (128, 128, 128), (128, 0, 0), (128, 128, 0), (0, 128, 0), (128, 0, 128), (0, 128, 128), (0, 0, 128)]
    if color_bg:
        bg = color_bg
    else:
        bg = sample(colors, 1)[0]
    try:
        img = Image.new('RGB', (300, 300), color=bg)
    except:
        print("Invalid color")
        print("Color has been randomly selected")
        bg = sample(colors, 1)[0]
        img = Image.new('RGB', (300, 300), color=bg)
    width, height = img.size
    draw = ImageDraw.Draw(img)
    font = ImageFont.truetype('arial.ttf', size=height)
    text = string.upper()
    color = 'rgb(255, 255, 255)'
    draw.text((width/2, height/2), text[0], fill=color, font=font, anchor='mm')
    return img






from setuptools import setup, find_packages

VERSION = '0.0.2'
DESCRIPTION = 'a package that generates profile picture from your name'
LONG_DESCRIPTION = 'A package to generate profile picture from a given string and gives you the option to choose the background color of the image. It is a simple package that can be used in any python project. Eg: django, flask, etc. '

# Setting up
setup(
    name="demoProfile",
    version=VERSION,
    author="Sheikh Umaid",
    author_email="sheikhumaid@pm.me",
    description=DESCRIPTION,
    long_description_content_type="text/markdown",
    long_description=LONG_DESCRIPTION,
    packages=find_packages(),
    install_requires=['pillow'],
    keywords=['demo', 'profile_picture', 'alphabet profile', 'django', 'sheikh umaid'],
    classifiers=[
        "Development Status :: 1 - Planning",
        "Intended Audience :: Developers",
        "Programming Language :: Python :: 3",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
    ]
)